package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.ExtendContent;
import com.huiju.estateagents.service.IExtendContentService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 辅助内容表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-25
 */
@RestController
@RequestMapping("/api")
public class ExtendContentController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(ExtendContentController.class);

    @Autowired
    public IExtendContentService iExtendContentService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/extendContent",method= RequestMethod.GET)
    public ResponseBean extendContentList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<ExtendContent> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<ExtendContent> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<ExtendContent> result = iExtendContentService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param extendContent 实体对象
     * @return
     */
    @RequestMapping(value="/extendContent",method= RequestMethod.POST)
    public ResponseBean extendContentAdd(@RequestBody ExtendContent extendContent){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iExtendContentService.save(extendContent)){
                responseBean.addSuccess(extendContent);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/extendContent/{id}", method= RequestMethod.DELETE)
    public ResponseBean extendContentDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iExtendContentService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param extendContent 实体对象
     * @return
     */
    @RequestMapping(value="/extendContent/{id}",method= RequestMethod.PUT)
    public ResponseBean extendContentUpdate(@PathVariable Integer id,
                                        @RequestBody ExtendContent extendContent){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iExtendContentService.updateById(extendContent)){
                responseBean.addSuccess(extendContent);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/extendContent/{id}",method= RequestMethod.GET)
    public ResponseBean extendContentGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iExtendContentService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
